@@ -27,6 +27,16 @@ class EventKind(IntEnum):
 
 
 class Event:
+    __slots__ = (
+        "id",
+        "pubkey",
+        "created_at",
+        "kind",
+        "content",
+        "tags",
+        "sig",
+    )
+
     def __init__(
             self,
             pubkey: str='', 
@@ -75,21 +85,6 @@ class Event:
     def compute_id(public_key: str, created_at: int, kind: int, tags: "list[list[str]]", content: str) -> str:
         return sha256(Event.serialize(public_key, created_at, kind, tags, content)).hexdigest()
 
-    @staticmethod
-    def from_tuple(row):
-        tags = row[4]
-        if isinstance(tags, str):
-            tags = loads(tags)
-        return Event(
-            id=row[0].hex(),
-            created_at=row[1],
-            kind=row[2],
-            pubkey=row[3].hex(),
-            tags=tags,
-            sig=row[5].hex(),
-            content=row[6],
-        )
-
     def sign(self, private_key_hex: str) -> None:
         sk = PrivateKey(bytes.fromhex(private_key_hex))
         sig = sk.schnorr_sign(bytes.fromhex(self.id), None, raw=True)
@@ -140,17 +135,6 @@ class Event:
         message.append(self.to_json_object())
         return dumps(message)
 
-    def to_tuple(self):
-        return (
-            self.id,
-            self.pubkey,
-            self.created_at,
-            self.kind,
-            dumps(self.tags),
-            self.content,
-            self.sig
-        )
-
     def __str__(self):
         return dumps(self.to_json_object())
 
